#!/bin/bash
[ "$#" -lt 1 ] && { echo "At least 1 argument required (the VM name), $# provided."; exit 1; }
[ "$(whoami)" != 'root' ] && { echo "You must be root to run this script!"; exit 1; }

#don't assume we have the helper scripts in the path...
toolpath="/usr/lib/xen_drbd"
server=`cat /etc/xen_drbd/server`
vg=`cat /etc/xen_drbd/vg`

#let's automatically check to see if we need to replicate the swap.
#you could just unset swap to make it false, but then it would be harder to pass over ssh...
if [ -e /dev/${vg}/${1}-swap ]
then
        echo "Alert: Swap detected."
        swap=1
else
        echo "Alert: Swap not detected."
        swap=0
fi

drbdadm net-options --protocol=C --allow-two-primaries ${1}-disk
if [ $swap -eq 1 ]
then
   drbdadm net-options --protocol=C --allow-two-primaries ${1}-swap
fi

#the migrate command will take care of this if it is a drbd: device in the xen
#cfg, but it doesn't hurt to do it anyway (so we can support phy: devices)
if [ $swap -eq 1 ]
then
   ssh $server "drbdadm primary ${1}-disk && drbdadm primary ${1}-swap"
else
   ssh $server "drbdadm primary ${1}-disk"
fi

xm migrate --live $1 $server

if [ $swap -eq 1 ]
then
   drbdadm secondary ${1}-swap
   drbdadm net-options --protocol=A --allow-two-primaries=no ${1}-swap
fi

drbdadm secondary ${1}-disk
drbdadm net-options --protocol=A --allow-two-primaries=no ${1}-disk
