#!/bin/bash
[ "$#" -ne 5 ] && { echo "5 arguments required, $# provided."; exit 1; }
[ "$(whoami)" != 'root' ] && { echo "You must be root to run this script!"; exit 1; }

#perhaps we should put a wrapper around this which remembers the minor number and reverts it if everything fails.  Also, it could delete any generated files so we aren't in a bad state (it should check to make sure they didn't exist in the first place though...

toolpath="/usr/lib/xen_drbd"

#no way to specify VG on remote yet...
vg=`cat /etc/xen_drbd/vg`

#sanity checks
[ -e /dev/${vg}/${1}-disk ] && { echo "The Logical Volume /dev/${vg}/${1}-disk already exists on the remote server!  Are you trying to replicate a VM that has already been replicated?"; exit 1; }
[ -e /etc/drbd/${1}.res ] && { echo "Error!  It appears this VM has already been setup for DRBD on the remote server."; exit 1; }

xm list | egrep "^${1}\s+" &> /dev/null

running=$?

if [ $running -ne 1 ]; then
   echo "Error: VM is running!"
   exit 1;
fi

swap=$3
#create the initial logical volumes
lvcreate -L${4}M -n ${1}-disk $vg

if [ $swap -eq 1 ]
then
	lvcreate -L${5}M -n ${1}-swap $vg
fi

#create the drbd resource file
#this has to be run as sudo, so we want to make sure to have the full path

mnum=`cat /etc/xen_drbd/minor`
pnum=`expr $mnum + 7789`
sed "s/resource_name/${1}-disk/g" $toolpath/drbd.res |sed "s/mnum/${mnum}/g" |sed "s/pnum/${pnum}/g" > /etc/drbd.d/${1}.res

if [ $swap -eq 1 ]
then
	mnum=`expr $mnum + 1`
	pnum=`expr $mnum + 7789`
	sed "s/resource_name/${1}-swap/g" $toolpath/drbd.res |sed "s/mnum/${mnum}/g" |sed "s/pnum/${pnum}/g" >> /etc/drbd.d/${1}.res
fi
expr $mnum + 1 > /etc/xen_drbd/minor

if [ $mnum -ne $2 ]
then
  echo "Error! The minor numbers are not aligned.  Remote server (this server) has $mnum, and local server has $2 THIS IS BAD!!!"
  exit 1;
fi
#todo: add rsync or something here to make sure minor lines up, as do the tools, and the .res files in /etc/drbd.d


#create the metadata on the resource
#over ssh we want to make this automatic, so use force.  Also, we just created the volumes, so this should be fine.
drbdadm -- --force create-md ${1}-disk


#bring it up
drbdadm up ${1}-disk

if [ $swap -eq 1 ]
then
	drbdadm -- --force create-md ${1}-swap
	drbdadm up ${1}-swap
fi

#since these are secondaries, we don't need to promote them to primary.
